Lang

Struct Lang 

pub struct Lang(pub LanguageIdentifier);
Identifies the language, region and script of text.

Use the lang! macro to construct one, it does compile-time validation.

Use the unic_langid crate for more advanced operations such as runtime parsing and editing identifiers, this type is just an alias for the core struct of that crate.

Tuple Fields

0: LanguageIdentifier

Implementations

Source

impl Lang

pub fn direction(&self) -> LayoutDirection

Returns character direction of the language.

pub fn matches( &self, other: &Self, self_as_range: bool, other_as_range: bool, ) -> bool

Compares a language to another allowing for either side to use the missing fields as wildcards.

This allows for matching between en (treated as en-*-*-*) and en-US.

Examples
let l1 = lang!("en");
let l2 = lang!("en-US");

assert_ne!(l1, l2); // "en" != "en-US"
assert!(!l1.matches(&l2, false, false)); // "en" != "en-US"

assert!(l1.matches(&l2, true, false)); // "en-*-*-*" == "en-US"
assert!(!l1.matches(&l2, false, true)); // "en" != "en-*-US-*"
assert!(l1.matches(&l2, true, true)); // "en-*-*-*" == "en-*-US-*"

Note that machine variant is ignored when matching.


let pt_br = lang!("pt-BR");
let pt_pt = lang!("pt-PT");
let pt = lang!("pt");
let pt_m = lang!("pt-machine");

assert!(!pt_br.matches(&pt_pt, true, false)); // "pt-BR-*-*" != "pt-PT"
assert!(pt.matches(&pt_pt, true, false)); // "pt-*-*-*" == "pt-PT"
assert!(pt_m.matches(&pt_pt, true, false)); // "pt-machine-*-*" == "pt-PT"

assert!(pt_m.matches(&pt, false, false)); // "pt-machine" == "pt"
assert_ne!(pt_m, pt); // but "pt-machine" != "pt" in `PartialEq`
pub fn is_machine_translation(&self) -> bool

If the language has a machine variant.

Machine translated resources are expected to be of lesser quality, but better than nothing. This variant indicates that the resource should be given lower priority. If a machine generated resource if reviewed by a human translator the machine variant must be removed.

pub fn autonym(&self) -> Option<LangAutonym>

Returns the name of the language and region in own language.

The names are in localized title case, when the name is the same in different scripts the script name is part of the language name (currently Hans/Hant).

Returns None if the locale is not one of the 90 most common locales embedded. Language must match, script must match exactly (omitted different from explicit), region is optional (if not matched returns only language name), variants are ignored.

pub fn cmp_display(&self, other: &Self) -> Ordering

Get ordering of this and other as fmt::Display text.

This method avoids actually allocating a string.

Methods from Deref<Target = LanguageIdentifier>

pub fn matches<O>( &self, other: &O, self_as_range: bool, other_as_range: bool, ) -> bool
where O: AsRef<LanguageIdentifier>,

Compares a LanguageIdentifier to another AsRef<LanguageIdentifier allowing for either side to use the missing fields as wildcards.

This allows for matching between en (treated as en-*-*-*) and en-US.

Examples
use unic_langid_impl::LanguageIdentifier;

let li1: LanguageIdentifier = "en".parse()
    .expect("Parsing failed.");

let li2: LanguageIdentifier = "en-US".parse()
    .expect("Parsing failed.");

assert_ne!(li1, li2); // "en" != "en-US"
assert_ne!(li1.to_string(), li2.to_string()); // "en" != "en-US"

assert_eq!(li1.matches(&li2, false, false), false); // "en" != "en-US"
assert_eq!(li1.matches(&li2, true, false), true); // "en-*-*-*" == "en-US"
assert_eq!(li1.matches(&li2, false, true), false); // "en" != "en-*-US-*"
assert_eq!(li1.matches(&li2, true, true), true); // "en-*-*-*" == "en-*-US-*"

pub fn variants(&self) -> impl ExactSizeIterator

Returns a vector of variants subtags of the LanguageIdentifier.

Examples
use unic_langid_impl::LanguageIdentifier;

let li1: LanguageIdentifier = "ca-ES-valencia".parse()
    .expect("Parsing failed.");

assert_eq!(li1.variants().map(|v| v.as_str()).collect::<Vec<_>>(), &["valencia"]);

let li2: LanguageIdentifier = "de".parse()
    .expect("Parsing failed.");

assert_eq!(li2.variants().len(), 0);

pub fn has_variant(&self, variant: Variant) -> bool

Tests if a variant subtag is present in the LanguageIdentifier.

Examples
use unic_langid_impl::LanguageIdentifier;

let mut li: LanguageIdentifier = "ca-ES-macos".parse()
    .expect("Parsing failed.");

assert_eq!(li.has_variant("valencia".parse().unwrap()), false);
assert_eq!(li.has_variant("macos".parse().unwrap()), true);

pub fn character_direction(&self) -> CharacterDirection

Returns character direction of the LanguageIdentifier.

Examples
use unic_langid_impl::{LanguageIdentifier, CharacterDirection};

let li1: LanguageIdentifier = "es-AR".parse()
    .expect("Parsing failed.");
let li2: LanguageIdentifier = "fa".parse()
    .expect("Parsing failed.");

assert_eq!(li1.character_direction(), CharacterDirection::LTR);
assert_eq!(li2.character_direction(), CharacterDirection::RTL);