pub struct LangAutonym {
pub language: &'static str,
pub region: Option<&'static str>,
}Expand description
Represents the translated name of a language and region in own language, using the selected script.
Fields
language: &'static strLanguage name in its own language.
region: Option<&'static str>Region name in the language.
Can be None when a region was requested and only the language name was available.